@@ -34,7 +34,7 @@ class Assistant:
         self.assistant.set_icon_name("pearlupdate-release-upgrade")
 
         if not os.path.exists("/etc/pearllinux/info"):
-            self.show_message('/usr/lib/pearllinux/pearlUpdate/rel_upgrades/failure.png', _("Your system is missing critical components. A package corresponding to your edition of Linux Mint should provide the virtual package 'pearl-info' and the file /etc/pearllinux/info."))
+            self.show_message('/usr/lib/pearllinux/pearlUpdate/rel_upgrades/failure.png', _("Your system is missing critical components. A package corresponding to your edition of Pearl Linux should provide the virtual package 'pearl-info' and the file /etc/pearllinux/info."))
         else:
             self.current_codename = 'unknown'
             self.current_edition = 'unknown'
@@ -56,7 +56,7 @@ class Assistant:
                 self.rel_editions = config['general']['editions']
                 if self.current_edition.lower() in self.rel_editions:
                     label = Gtk.Label()
-                    label.set_markup(_("A new version of Linux Mint is available!"))
+                    label.set_markup(_("A new version of Pearl Linux is available!"))
                     self.vbox_intro.pack_start(label, False, False, 6)
                     image = Gtk.Image.new_from_file(os.path.join(rel_path, "%s.png" % self.current_edition.lower()))
                     self.vbox_intro.pack_start(image, False, False, 0)
