@@ -3,7 +3,7 @@
 import os, sys, apt, tempfile, gettext
 import subprocess
 
-gettext.install("pearlupdate", "/usr/share/pearllinux/locale")
+gettext.install("pearlupdate", "/usr/share/locale")
 
 if os.getuid() != 0:
     print("Run this code as root!")
@@ -52,13 +52,7 @@ cache.open(None)
 cache.upgrade(dist_upgrade)
 changes = cache.get_changes()
 
-cmd = ["sudo", "/usr/sbin/synaptic", "--hide-main-window", "--non-interactive", "--parent-window-id", "%s" % window_id]
-cmd.append("-o")
-cmd.append("Synaptic::closeZvt=true")
-cmd.append("--progress-str")
-cmd.append("\"" + _("Please wait, this can take some time") + "\"")
-cmd.append("--finish-str")
-cmd.append("\"" + _("Update is complete") + "\"")
+cmd = ["sudo", "/usr/sbin/synaptic", "--hide-main-window", "--non-interactive", "--parent-window-id", "%s" % window_id, "-o", "Synaptic::closeZvt=true"]
 f = tempfile.NamedTemporaryFile()
 
 for pkg in changes:
@@ -89,13 +83,6 @@ returnCode = comnd.wait()
 #--------------------
 
 try:
-    if os.path.exists("/etc/grub.d/10_linux"):
-        if os.path.exists("/etc/pearllinux/info"):
-            pearl_grub_title = subprocess.getoutput("grep GRUB_TITLE /etc/pearllinux/info | awk -F = '{print $2}'")
-        else:
-            pearl_grub_title = "Pearl Linux"
-        os.system("sed -i -e 's@OS=\"${GRUB_DISTRIBUTOR}\"@OS=\"%s\"@g' /etc/grub.d/10_linux" % pearl_grub_title)
-        os.system("sed -i -e 's@OS=\"Pearl Linux .*@OS=\"%s\"@g' /etc/grub.d/10_linux" % pearl_grub_title)
-        subprocess.call("update-grub")
+    subprocess.call("update-grub")
 except Exception as detail:
-    syslog.syslog("Couldn't update grub: %s" % detail)
+    syslog.syslog("Couldn't update grub: %s" % detail)
\ No newline at end of file
